@@ -48,15 +48,16 @@ define([
         /**
          * 
          * @param {*} initialData 
-         * @param {*} extensionType      extension type: notebook/colab/lab
+         * @param {*} extensionType      extension type: notebook/colab/lab/lite
          */
         constructor(extensionType='notebook', initialData={}) {
             // initial mode
+            this.isReady = false;
             this.extensionType = extensionType;
             this.parentSelector = 'body';
             if (extensionType === 'notebook') {
                 this.parentSelector = '#site';
-            } else if (extensionType === 'colab' || extensionType === 'lab') {
+            } else if (extensionType === 'colab' || extensionType === 'lab' || extensionType === 'lite') {
                 // this.parentSelector = '.notebook-horizontal';
                 this.parentSelector = 'body';
             }
@@ -295,6 +296,7 @@ define([
          * - automatically restart on jupyter kernel restart (loadVisualpython.js)
          */
         readKernelFunction() {
+            let that = this;
             // CHROME: change method to load py files ($.get -> require)
             return new Promise(function(resolve, reject) {
                 var libraryList = [ 
@@ -313,7 +315,26 @@ define([
                 libraryList.forEach(libCode => {
                     promiseList.push(vpKernel.execute(libCode, true));
                 });
-                
+
+                if (that.extensionType === 'lite') {
+                    let preInstallCode = '';
+                    let preInstallPackList = [
+                        'seaborn',
+                        'plotly',
+                        'scikit-learn',
+                        'scipy',
+                        'statsmodels'
+                    ];
+                    preInstallPackList.forEach((packName, idx) => {
+                        preInstallCode += '%pip install ' + packName
+                        if (idx < preInstallPackList.length - 1) {
+                            preInstallCode += '\n';
+                        }
+                    });
+                    // pre-install packages
+                    promiseList.push(vpKernel.execute(preInstallCode, true));
+                }
+
                 // run all promises
                 let failed = false;
                 Promise.all(promiseList).then(function(resultObj) {
@@ -463,8 +484,8 @@ define([
                         // not mounted
                         reject('Colab Drive is not mounted!');
                     })
-                } else if (that.extensionType === 'lab') {
-                    // CHROME: edited to use .visualpython files
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
+                    // LAB: edited to use .visualpython files
                     that._readFromLab('', configKey).then(function(result) {
                         resolve(result);
                     }).catch(function(err) {
@@ -526,7 +547,7 @@ define([
                         // not mounted
                         reject('Colab Drive is not mounted!');
                     })
-                } else if (that.extensionType === 'lab') {
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
                     // LAB: use local .visualpython files
                     that._readFromLab(configKey).then(function(result) {
                         let data = result;
@@ -604,7 +625,7 @@ define([
                             reject();
                         });
                     });
-                } else if (that.extensionType === 'lab') {
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
                     // LAB: use .visualpython files
                     that.getData('', configKey).then(function(data) {
                         let newDataObj = {};
@@ -649,7 +670,7 @@ define([
                     }).catch(function(err) {
                         reject(false);
                     })
-                } else if (that.extensionType === 'lab') {
+                } else if (that.extensionType === 'lab' || that.extensionType === 'lite') {
                     // LAB: use .visualpython files
                     that.getData('', configKey).then(function(data) {
                         let dataObj = data;
@@ -838,7 +859,7 @@ define([
             let that = this;
             let nowVersion = this.getVpInstalledVersion();
             let packageName = 'visualpython';
-            if (this.extensionType === 'lab') {
+            if (this.extensionType === 'lab' || this.extensionType === 'lite') {
                 packageName = 'jupyterlab-visualpython';
             }
             this.getPackageVersion(packageName).then(function(latestVersion) {
@@ -908,6 +929,16 @@ define([
                                         ];
                                         com_interface.insertCell('markdown', info.join('\n'));
                                         com_interface.insertCell('code', '!pip install jupyterlab-visualpython --upgrade');
+                                    } else if (that.extensionType === 'lite') {
+                                        // LITE: update lab extension on lite
+                                        let info = [
+                                            '## Visual Python Upgrade',
+                                            'NOTE: ',
+                                            '- Refresh your web browser to start a new version.',
+                                            '- Save VP Note before refreshing the page.'
+                                        ];
+                                        com_interface.insertCell('markdown', info.join('\n'));
+                                        com_interface.insertCell('code', "%pip install jupyterlab-visualpython==" + latestVersion);
                                     }
 
                                     // update version_timestamp
@@ -980,7 +1011,7 @@ define([
     /**
      * Version
      */
-    Config.version = "2.4.0";
+    Config.version = "2.4.2";
 
     /**
      * Type of mode
